pub struct Lexer<'src> {
pub errors: Vec<LexerError>,
/* private fields */
}Fields
errors: Vec<LexerError>Implementations
Sourceimpl<'src> Lexer<'src>
impl<'src> Lexer<'src>
pub fn new(source: &'src str) -> Self
Sourcepub fn new_at(source: &'src str, offset: usize) -> Self
pub fn new_at(source: &'src str, offset: usize) -> Self
Create a lexer starting in PHP mode at a given byte offset within source.
The caller guarantees that source[offset..] contains valid PHP expression
content (no <?php tag needed — the lexer is pre-set to PHP mode).
Spans produced will be correct absolute offsets into source.
pub fn source(&self) -> &'src str
pub fn peek(&mut self) -> &Token
pub fn next_token(&mut self) -> Token
Sourcepub fn token_text(&self, token: &Token) -> &'src str
pub fn token_text(&self, token: &Token) -> &'src str
Get the text slice corresponding to a token